"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerateActionCLI = void 0;
const fs = require("fs");
const path = require("path");
const index_1 = require("./../../../index");
class GenerateActionCLI extends index_1.CLI {
    constructor() {
        super(...arguments);
        this.name = "generate-action";
        this.description = "Generate a new Action";
        this.example = "actionhero generate action --name=<name> --description=[description]";
        this.inputs = {
            name: {
                required: true,
                description: "The name of the Action to Generate",
                letter: "n",
            },
            description: {
                required: false,
                description: "The description of the Action",
                default: "an actionhero action",
                letter: "d",
            },
        };
    }
    async run({ params }) {
        let actionTemplateBuffer = fs.readFileSync(path.join(__dirname, "../../../../templates/action.ts.template"));
        let actionTemplate = actionTemplateBuffer.toString();
        let testTemplateBuffer = fs.readFileSync(path.join(__dirname, "/../../../../templates/test/action.ts.template"));
        let testTemplate = testTemplateBuffer.toString();
        for (const [k, v] of Object.entries(params)) {
            const regex = new RegExp("%%" + k + "%%", "g");
            actionTemplate = actionTemplate.replace(regex, v);
            testTemplate = testTemplate.replace(regex, v);
        }
        let message = index_1.utils.fileUtils.createFileSafely(index_1.utils.replaceDistWithSrc(index_1.config.general.paths.action[0]) +
            "/" +
            params.name +
            ".ts", actionTemplate);
        console.info(message);
        message = index_1.utils.fileUtils.createFileSafely(index_1.config.general.paths.test[0] + "/actions/" + params.name + ".ts", testTemplate);
        console.info(message);
        return true;
    }
}
exports.GenerateActionCLI = GenerateActionCLI;
